==> 3.6.8.zip: source-immo/scripts/ang.public-app/ang.factories.compiler.js <==

siApp
.factory('$siCompiler', ['$siConfig','$siList', '$siUtils','$siLexicon','$siDictionary',
function $siCompiler($siConfig,$siList, $siUtils,$siLexicon,$siDictionary){
    const $scope = {};

    $scope.init = function(){
        $siConfig.get().then(function ($configs){
            $scope.configs = $configs;
        });
    }

    /**
     * Compile data to ease access to some values
     * @param {array} $list Array of listing item
     */
    $scope.compileListingList = function($list){
        
        $list.forEach(function($e){
            $scope.compileListingItem($e);
        });

        return $list;
    }

    $scope.compileListingItem = function($item){
        
        if($item.category == undefined){
            $item.counters = {};

            
            $item.subcategory = $siUtils.getCaption($item.subcategory_code, 'listing_subcategory');
            $item.category = $siUtils.getCaption($item.category_code, 'listing_category');
            $item.transaction = $siUtils.getTransaction($item);
            
            

            $item.short_price = $siUtils.formatPrice($item);
            $item.location = $scope.compileLocation($item.location, $item);
            
            if(!isNullOrEmpty($item.available_area)){
                $item.available_area_unit = $siUtils.getCaption($item.available_area_unit_code,'dimension_unit',true);
            }

            $scope.compileListingRooms($item);
            $item.permalink = $siUtils.getPermalink($item);

        }

        $scope.compileListingTags($item);
        $scope.compileItemTags($item);

    }

    $scope.compileLocation = function($location, $item=null){
        if(isNullOrUndefined($location)) return null;
        const location = Object.assign({}, $location);

        location.city = (location.city != undefined) ? location.city : $siUtils.getCaption(location.city_code, 'city');
        location.region = (location.region != undefined) ? location.region : $siUtils.getCaption(location.region_code, 'region');
        location.district  = (location.district != undefined) ? location.district : $siUtils.getCaption(location.district_code, 'district');
        location.full_address = [];

        location.full_address.push(location.city);
        location.full_address.push(location.region);
        location.full_address.push(location.country);
        
        if(!isNullOrEmpty(location.address)){
            if(!isNullOrEmpty(location.address.street_name)){
                location.civic_address = '{0} {1}'.siFormat(
                    location.address.street_number || '',
                    location.address.street_name
                ).trim();

                if(!isNullOrEmpty(location.address.door)){
                    let doorType = $siLexicon.get('apt.'.siTranslate());
                    if($item!=null && ['COM','IND'].includes($item.category_code)){
                        doorType = $siLexicon.get('suite'.siTranslate());
                    }
                    
                    location.civic_address += ', ' + '{1} {0}'.siFormat(location.address.door,doorType);
                }
            }
        }

        if(!isNullOrEmpty(location.civic_address)){
            // location.full_address = '{0} {1}, {2}'.siFormat(
            //     location.address.street_number || '',
            //     location.address.street_name,
            //     location.city
            // );

            location.civic_address = location.civic_address.replace(/\{\d{1,3}\}/g, '');
            location.full_address.unshift(location.civic_address);
            // if(!isNullOrEmpty(location.address.door) && typeof  location.address.door != 'undefined'){
            //     location.full_address += ', ' + '{1} {0}'.siFormat( location.address.door, doorType);
            // }
        }
        else{
            
            // location.full_address = '{0}, {2}'.siFormat(
            //     location.city, 
            //     location.country
            // );
        }

        // remove empty 
        location.full_address = location.full_address.filter(p => !isNullOrEmpty(p)).join(', ');
        if(isNullOrEmpty(location.civic_address)){
            location.civic_address = location.full_address;
        }
        //if(location.full_address) location.full_address = location.full_address.replace(/\{\d{1,3}\}/g, '');


        return location;
    }

    // Add tags to listing item
    $scope.compileListingTags = function($item){
        $item.tags = [];

        if($siConfig._data && $siConfig._data.new_item_time_limit > 0 ){
            const date = ($item.contract && $item.contract.start_date) 
                            ? $item.contract.start_date
                            : $item.creation_date;
            if(date != undefined){
                if(moment(date).isValid()){
                    if(moment(date).isAfter(moment().add(-1 * $siConfig._data.new_item_time_limit,'day'))){
                        $item.tags.push({label: 'New'});
                    }
                }
            }
        }

        if($item.availability_delay!=undefined && $item.availability_delay <= 10) $item.tags.push({label: 'Quick move-in'});
        if($item.for_rent_flag || $item.price.rent) $item.tags.push({label: 'For rent'});
        if($item.video_flag) $item.tags.push({label: 'Video'});
        if($item.virtual_tour_flag) $item.tags.push({label: 'Virtual tour'});

        if($item.attributes != undefined){
            let attrs = $item.attributes;
            if(Array.isArray(attrs)){ attrs = attrs.reduce( (o, e) => {
                    o[e.code] = true;
                    if(Array.isArray(e.values)){
                        e.values.forEach(v => { o[v.code] = true});
                    }
                    return o;
                }, {});
            }

            if(attrs.PANORAMIC_VIEW === true || attrs['VIEW PANORAMIC'] === true) $item.tags.push({label: 'Panoramic view'});
            if(attrs.WATER_FRONT === true || attrs['VIEW WATER'] === true) $item.tags.push({label: 'Water front'});
            if(attrs.POOL === true) $item.tags.push({label: 'Pool'});
        }

    }

    $scope.compileListingMapMarker = function($item){
        $item.category = $siUtils.getCaption($item.category_code, 'listing_category');
        $item.status = $siUtils.getCaption($item.status_code, 'listing_status');
    }

    /**
     * Compile data to ease access to some values
     * @param {array} $list Array of broker item
     */
    $scope.compileBrokerList = function($list){
        $siConfig.get().then(function ($configs){
            $siList.getOfficeList($configs.default_view);
        });

        $list.forEach(function($e){
            $scope.compileBrokerItem($e);
        });

        return $list;
    }

    $scope.compileBrokerItem = function($item){

        if($item.office_ref_number != undefined){
            $officeList = $siList.getOfficeList();
            $item.office = $officeList.find(function($e) { return $e.ref_number == $item.office_ref_number});
            $scope.compileOfficeItem($item.office);

            
        }

        if($item.phones != null){
            if($item.phones.office == undefined && $item.office != undefined){
                $item.phones.office = $item.office.phones.office_toll_free ? $item.office.phones.office_toll_free : $item.office.phones.office;
            }
            Object.keys($item.phones).forEach(function($key) { $item.phones[$key] = $siUtils.formatPhone($item.phones[$key]);}); 
        }

        $item.fullname = $item.first_name + ' ' + $item.last_name;
        

        
        if($item.license_type==undefined){
            $item.license_type = $siLexicon.get($siUtils.getCaption($item.license_type_code, 'broker_license_type'));
        }

        if($item.permalink == undefined){
            $item.permalink = $siUtils.getPermalink($item,'broker');
        }

        $scope.compileLinks($item);
    }

    $scope.compileListingRooms = function($item){
        if($item.main_unit == undefined && $item.units != undefined){
            if($item.units.length > 0) $item.main_unit = $item.units.find(function($u){ return $u.category_code == 'MAIN'});
        }

        const lIconRef = {
            'bathroom_count' : 'bath',
            'bedroom_count' : 'bed',
            'waterroom_count' : 'hand-holding-water'
        }
        const lLabelRef = {
            'bathroom_count' : 'Bathroom',
            'bedroom_count' : 'Bedroom',
            'waterroom_count' : 'Powder room'
        }
        const lPluralLabelRef = {
            'bathroom_count' : 'Bathrooms',
            'bedroom_count' : 'Bedrooms',
            'waterroom_count' : 'Powder rooms'
        }

        if($item.rooms != undefined && $item.main_unit == undefined){
            $item.main_unit = {
                'bathroom_count' : $item.rooms.filter(r => ['BTH'].includes(r.category_code)).length,
                'waterroom_count' : $item.rooms.filter(r => ['xxx'].includes(r.category_code)).length,
                'bedroom_count' : $item.rooms.filter(r => ['MBR','BDR'].includes(r.category_code)).length
            }
        }

        if(typeof $item.main_unit != 'undefined'){
            
            

            $item.counters.rooms = {};

            Object.keys($item.main_unit).forEach(function($k){
                if($item.main_unit[$k] > 0){
                    const lLabel = $item.main_unit[$k] > 1 ? lPluralLabelRef[$k] : lLabelRef[$k];
                    
                    if(typeof lIconRef[$k] != 'undefined') $item.counters.rooms[lIconRef[$k]] = {count : $item.main_unit[$k], label : lLabel};
                }
            });
        }

    }

    /**
     * Compile data to ease access to some values
     * @param {array} $list Array of office item
     */
    $scope.compileOfficeList = function($list){
        $list.forEach(function($e){
            $scope.compileOfficeItem($e);
        })
        return $list;
    }
    
    $scope.compileOfficeItem = function($item){
        if($item == undefined) return;
        if($item.phones != null){
            Object.keys($item.phones).forEach(function($key) { $item.phones[$key] = $siUtils.formatPhone($item.phones[$key]);}); 
        }
        $item.location.region       = ($item.location.region == undefined) ? $siUtils.getCaption($item.location.region_code, 'region') : $item.location.region;
        $item.location.country      = ($item.location.country == undefined) ? $siUtils.getCaption($item.location.country_code, 'country') : $item.location.country;
        $item.location.state        = ($item.location.state == undefined) ? $siUtils.getCaption($item.location.state_code, 'state') : $item.location.state;
        $item.location.city         = ($item.location.city == undefined) ? $siUtils.getCaption($item.location.city_code, 'city') : $item.location.city;
        
        $item.location.street_address = '{0} {1}'.siFormat(
                                                    $item.location.address.street_number,
                                                    $item.location.address.street_name
                                                );
        if(!isNullOrEmpty($item.location.address.door)){
            $item.location.street_address += ', suite {0}'.siTranslate().siFormat($item.location.address.door);
        }
        $item.location.full_address = '{0} {1}, {2}'.siFormat(
                                                $item.location.address.street_number,
                                                $item.location.address.street_name,
                                                $item.location.city
                                            );
        if($item.agency) $scope.compileAgencyItem($item.agency);
        $scope.compileLinks($item);

        $item.permalink = $siUtils.getPermalink($item,'office');
    }

   /**
     * Compile data to ease access to some values
     * @param {array} $list Array of office item
     */
    $scope.compileAgencyList = function($list){
        

        $list.forEach(function($e){
            $scope.compileAgencyItem($e);
        });

        return $list;
    }
    
    $scope.compileAgencyItem = function($item){
        if($item == undefined) return;
        if($item.phones != null){
            Object.keys($item.phones).forEach(function($key) { $item.phones[$key] = $siUtils.formatPhone($item.phones[$key]);}); 
        }
        
        $item.franchisor = $siUtils.getCaption($item.franchisor_code, 'franchisor');
        $item.license_type = ($item.license_type_code != undefined) ? $siUtils.getCaption($item.license_type_code, 'agency_license_type') : $item.license_type;

        if($item.main_office != null){
            $scope.compileOfficeItem($item.main_office);
            $item.location = $item.main_office.location;
        }
        
        $item.permalink = $siUtils.getPermalink($item,'agency');
    }

    $scope.compileCityList = function($list){
        $list.forEach(function($e){
            $scope.compileCityItem($e);
        });
    }

    $scope.compileCityItem = function($item){
        $item.region    = $siUtils.getCaption($item.region_code, 'region');
        $item.country   = $siUtils.getCaption($item.country_code, 'country');
        $item.state     = $siUtils.getCaption($item.state_code, 'state');
        $item.city      = $siUtils.getCaption($item.city_code, 'city');

        $item.permalink = $siUtils.getPermalink($item,'city');
    }

    $scope.compileLinks = function($item){
        if($item.links != undefined){
            $item.links.socials = Object.keys($item.links).filter($k => $k!='website').map($k => {
                return {
                    type: $k,
                    url: $item.links[$k]
                }
            });
        }
    }

    $scope.compileItemTags = function($item){
        return;
        // console.log('compileItemTags', $siDictionary.tags);

        if($item.tag_ids == null || $item.tag_ids == undefined) return;
        if($siDictionary.tags == null || $siDictionary.tags == undefined) return;

        if($item.tags == undefined) $item.tags = [];
        
        $siDictionary.tags
            .filter( t => $item.tag_ids.includes(t.id) && t.public)
            .forEach(t => {
                $item.tags.push({
                    icon: 'tag',
                    color: t.color,
                    label: t.description
                })
            })

    }


    $scope.init();

    return $scope;
}]);

==> 3.7.0.zip: source-immo/scripts/ang.public-app/ang.factories.compiler.js <==

siApp
.factory('$siCompiler', ['$siConfig','$siList', '$siUtils','$siLexicon','$siDictionary',
function $siCompiler($siConfig,$siList, $siUtils,$siLexicon,$siDictionary){
    const $scope = {};

    $scope.init = function(){
        $siConfig.get().then(function ($configs){
            $scope.configs = $configs;
        });
    }

    /**
     * Compile data to ease access to some values
     * @param {array} $list Array of listing item
     */
    $scope.compileListingList = function($list){
        
        $list.forEach(function($e){
            $scope.compileListingItem($e);
        });

        return $list;
    }

    $scope.compileListingItem = function($item){
        
        if($item.category == undefined){
            $item.counters = {};

            
            $item.subcategory = $siUtils.getCaption($item.subcategory_code, 'listing_subcategory');
            $item.category = $siUtils.getCaption($item.category_code, 'listing_category');
            $item.transaction = $siUtils.getTransaction($item);
            
            

            $item.short_price = $siUtils.formatPrice($item);
            $item.location = $scope.compileLocation($item.location, $item);
            
            if(!isNullOrEmpty($item.available_area)){
                $item.available_area_unit = $siUtils.getCaption($item.available_area_unit_code,'dimension_unit',true);
            }

            $scope.compileListingRooms($item);
            $item.permalink = $siUtils.getPermalink($item);

        }

        $scope.compileListingTags($item);
        $scope.compileItemTags($item);

    }

    $scope.compileLocation = function($location, $item=null){
        if(isNullOrUndefined($location)) return null;
        const location = Object.assign({}, $location);

        location.city = (location.city != undefined) ? location.city : $siUtils.getCaption(location.city_code, 'city');
        location.region = (location.region != undefined) ? location.region : $siUtils.getCaption(location.region_code, 'region');
        location.district  = (location.district != undefined) ? location.district : $siUtils.getCaption(location.district_code, 'district');
        location.full_address = [];

        location.full_address.push(location.city);
        location.full_address.push(location.region);
        location.full_address.push(location.country);
        
        if(!isNullOrEmpty(location.address)){
            if(!isNullOrEmpty(location.address.street_name)){
                location.civic_address = '{0} {1}'.siFormat(
                    location.address.street_number || '',
                    location.address.street_name
                ).trim();

                if(!isNullOrEmpty(location.address.door)){
                    let doorType = $siLexicon.get('apt.'.siTranslate());
                    if($item!=null && ['COM','IND'].includes($item.category_code)){
                        doorType = $siLexicon.get('suite'.siTranslate());
                    }
                    
                    location.civic_address += ', ' + '{1} {0}'.siFormat(location.address.door,doorType);
                }
            }
        }

        if(!isNullOrEmpty(location.civic_address)){
            // location.full_address = '{0} {1}, {2}'.siFormat(
            //     location.address.street_number || '',
            //     location.address.street_name,
            //     location.city
            // );

            location.civic_address = location.civic_address.replace(/\{\d{1,3}\}/g, '');
            location.full_address.unshift(location.civic_address);
            // if(!isNullOrEmpty(location.address.door) && typeof  location.address.door != 'undefined'){
            //     location.full_address += ', ' + '{1} {0}'.siFormat( location.address.door, doorType);
            // }
        }
        else{
            
            // location.full_address = '{0}, {2}'.siFormat(
            //     location.city, 
            //     location.country
            // );
        }

        // remove empty 
        location.full_address = location.full_address.filter(p => !isNullOrEmpty(p)).join(', ');
        if(isNullOrEmpty(location.civic_address)){
            location.civic_address = location.full_address;
        }
        //if(location.full_address) location.full_address = location.full_address.replace(/\{\d{1,3}\}/g, '');


        return location;
    }

    // Add tags to listing item
    $scope.compileListingTags = function($item){
        $item.tags = [];

        if($siConfig._data && $siConfig._data.new_item_time_limit > 0 ){
            const date = ($item.contract && $item.contract.start_date) 
                            ? $item.contract.start_date
                            : $item.creation_date;
            if(date != undefined){
                if(moment(date).isValid()){
                    if(moment(date).isAfter(moment().add(-1 * $siConfig._data.new_item_time_limit,'day'))){
                        $item.tags.push({label: 'New'});
                    }
                }
            }
        }

        if($item.availability_delay!=undefined && $item.availability_delay <= 10) $item.tags.push({label: 'Quick move-in'});
        if($item.for_rent_flag || $item.price.rent) $item.tags.push({label: 'For rent'});
        if($item.video_flag) $item.tags.push({label: 'Video'});
        if($item.virtual_tour_flag) $item.tags.push({label: 'Virtual tour'});

        if($item.attributes != undefined){
            let attrs = $item.attributes;
            if(Array.isArray(attrs)){ attrs = attrs.reduce( (o, e) => {
                    o[e.code] = true;
                    if(Array.isArray(e.values)){
                        e.values.forEach(v => { o[v.code] = true});
                    }
                    return o;
                }, {});
            }


            if(attrs.PANORAMIC_VIEW === true || attrs['VIEW PANORAMIC'] === true) $item.tags.push({label: 'Panoramic view'});
            if(attrs['DISTINCT. FEAT. WOODED'] === true) $item.tags.push({label: 'Wooded lot'});
            if(attrs['DISTINCT. FEAT. WATER FRONT'] === true) $item.tags.push({label: 'Water front'});
            else {
                if(attrs['DISTINCT. FEAT. WATER ACCESS'] === true) $item.tags.push({label: 'Water access'});
                else if(attrs.WATER_VIEW === true || attrs['VIEW WATER']) $item.tags.push({label: 'Water view'});
            }

            if(attrs.POOL === true){
                if(attrs['POOL INGROUND'] === true) $item.tags.push({label: 'Inground pool'});
                else{
                    $item.tags.push({label: 'Pool'});
                }
            }
        }

    }

    $scope.compileListingMapMarker = function($item){
        $item.category = $siUtils.getCaption($item.category_code, 'listing_category');
        $item.status = $siUtils.getCaption($item.status_code, 'listing_status');
    }

    /**
     * Compile data to ease access to some values
     * @param {array} $list Array of broker item
     */
    $scope.compileBrokerList = function($list){
        $siConfig.get().then(function ($configs){
            $siList.getOfficeList($configs.default_view);
        });

        $list.forEach(function($e){
            $scope.compileBrokerItem($e);
        });

        return $list;
    }

    $scope.compileBrokerItem = function($item){

        if($item.office_ref_number != undefined){
            $officeList = $siList.getOfficeList();
            $item.office = $officeList.find(function($e) { return $e.ref_number == $item.office_ref_number});
            $scope.compileOfficeItem($item.office);

            
        }

        if($item.phones != null){
            if($item.phones.office == undefined && $item.office != undefined){
                $item.phones.office = $item.office.phones.office_toll_free ? $item.office.phones.office_toll_free : $item.office.phones.office;
            }
            Object.keys($item.phones).forEach(function($key) { $item.phones[$key] = $siUtils.formatPhone($item.phones[$key]);}); 
        }

        $item.fullname = $item.first_name + ' ' + $item.last_name;
        

        
        if($item.license_type==undefined){
            $item.license_type = $siLexicon.get($siUtils.getCaption($item.license_type_code, 'broker_license_type'));
        }

        if($item.permalink == undefined){
            $item.permalink = $siUtils.getPermalink($item,'broker');
        }

        $scope.compileLinks($item);
    }

    $scope.compileListingRooms = function($item){
        if($item.main_unit == undefined && $item.units != undefined){
            if($item.units.length > 0) $item.main_unit = $item.units.find(function($u){ return $u.category_code == 'MAIN'});
        }

        const lIconRef = {
            'bathroom_count' : 'bath',
            'bedroom_count' : 'bed',
            'waterroom_count' : 'hand-holding-water'
        }
        const lLabelRef = {
            'bathroom_count' : 'Bathroom',
            'bedroom_count' : 'Bedroom',
            'waterroom_count' : 'Powder room'
        }
        const lPluralLabelRef = {
            'bathroom_count' : 'Bathrooms',
            'bedroom_count' : 'Bedrooms',
            'waterroom_count' : 'Powder rooms'
        }

        if($item.rooms != undefined && $item.main_unit == undefined){
            $item.main_unit = {
                'bathroom_count' : $item.rooms.filter(r => ['BTH'].includes(r.category_code)).length,
                'waterroom_count' : $item.rooms.filter(r => ['xxx'].includes(r.category_code)).length,
                'bedroom_count' : $item.rooms.filter(r => ['MBR','BDR'].includes(r.category_code)).length
            }
        }

        if(typeof $item.main_unit != 'undefined'){
            
            

            $item.counters.rooms = {};

            Object.keys($item.main_unit).forEach(function($k){
                if($item.main_unit[$k] > 0){
                    const lLabel = $item.main_unit[$k] > 1 ? lPluralLabelRef[$k] : lLabelRef[$k];
                    
                    if(typeof lIconRef[$k] != 'undefined') $item.counters.rooms[lIconRef[$k]] = {count : $item.main_unit[$k], label : lLabel};
                }
            });
        }

    }

    /**
     * Compile data to ease access to some values
     * @param {array} $list Array of office item
     */
    $scope.compileOfficeList = function($list){
        $list.forEach(function($e){
            $scope.compileOfficeItem($e);
        })
        return $list;
    }
    
    $scope.compileOfficeItem = function($item){
        if($item == undefined) return;
        if($item.phones != null){
            Object.keys($item.phones).forEach(function($key) { $item.phones[$key] = $siUtils.formatPhone($item.phones[$key]);}); 
        }
        $item.location.region       = ($item.location.region == undefined) ? $siUtils.getCaption($item.location.region_code, 'region') : $item.location.region;
        $item.location.country      = ($item.location.country == undefined) ? $siUtils.getCaption($item.location.country_code, 'country') : $item.location.country;
        $item.location.state        = ($item.location.state == undefined) ? $siUtils.getCaption($item.location.state_code, 'state') : $item.location.state;
        $item.location.city         = ($item.location.city == undefined) ? $siUtils.getCaption($item.location.city_code, 'city') : $item.location.city;
        
        $item.location.street_address = '{0} {1}'.siFormat(
                                                    $item.location.address.street_number,
                                                    $item.location.address.street_name
                                                );
        if(!isNullOrEmpty($item.location.address.door)){
            $item.location.street_address += ', suite {0}'.siTranslate().siFormat($item.location.address.door);
        }
        $item.location.full_address = '{0} {1}, {2}'.siFormat(
                                                $item.location.address.street_number,
                                                $item.location.address.street_name,
                                                $item.location.city
                                            );
        if($item.agency) $scope.compileAgencyItem($item.agency);
        $scope.compileLinks($item);

        $item.permalink = $siUtils.getPermalink($item,'office');
    }

   /**
     * Compile data to ease access to some values
     * @param {array} $list Array of office item
     */
    $scope.compileAgencyList = function($list){
        

        $list.forEach(function($e){
            $scope.compileAgencyItem($e);
        });

        return $list;
    }
    
    $scope.compileAgencyItem = function($item){
        if($item == undefined) return;
        if($item.phones != null){
            Object.keys($item.phones).forEach(function($key) { $item.phones[$key] = $siUtils.formatPhone($item.phones[$key]);}); 
        }
        
        $item.franchisor = $siUtils.getCaption($item.franchisor_code, 'franchisor');
        $item.license_type = ($item.license_type_code != undefined) ? $siUtils.getCaption($item.license_type_code, 'agency_license_type') : $item.license_type;

        if($item.main_office != null){
            $scope.compileOfficeItem($item.main_office);
            $item.location = $item.main_office.location;
        }
        
        $item.permalink = $siUtils.getPermalink($item,'agency');
    }

    $scope.compileCityList = function($list){
        $list.forEach(function($e){
            $scope.compileCityItem($e);
        });
    }

    $scope.compileCityItem = function($item){
        $item.region    = $siUtils.getCaption($item.region_code, 'region');
        $item.country   = $siUtils.getCaption($item.country_code, 'country');
        $item.state     = $siUtils.getCaption($item.state_code, 'state');
        $item.city      = $siUtils.getCaption($item.city_code, 'city');

        $item.permalink = $siUtils.getPermalink($item,'city');
    }

    $scope.compileLinks = function($item){
        if($item.links != undefined){
            $item.links.socials = Object.keys($item.links).filter($k => $k!='website').map($k => {
                return {
                    type: $k,
                    url: $item.links[$k]
                }
            });
        }
    }

    $scope.compileItemTags = function($item){
        return;
        // console.log('compileItemTags', $siDictionary.tags);

        if($item.tag_ids == null || $item.tag_ids == undefined) return;
        if($siDictionary.tags == null || $siDictionary.tags == undefined) return;

        if($item.tags == undefined) $item.tags = [];
        
        $siDictionary.tags
            .filter( t => $item.tag_ids.includes(t.id) && t.public)
            .forEach(t => {
                $item.tags.push({
                    icon: 'tag',
                    color: t.color,
                    label: t.description
                })
            })

    }


    $scope.init();

    return $scope;
}]);
